@@ -1,3 +1,8 @@
+from __future__ import print_function
+from __future__ import division
+
+from sys import version_info
+
 import pytest
 
 from mini_lambda import FunctionDefinitionError, make_lambda_friendly_method
@@ -24,7 +29,8 @@ def test_doc_index_1():
 def test_doc_index_2():
     """ Tests that the second example in the documentation main page works """
 
-    from mini_lambda import s, x, _, Log  # this is a dynamic creation hence pycharm does not see it
+    from mini_lambda import s, x, _  # this is a dynamic creation hence pycharm does not see it
+    from mini_lambda.symbols.math_ import Log
 
     # various lambda functions
     is_lowercase = _(s.islower())
@@ -140,7 +146,9 @@ def test_doc_usage_syntax_2():
     """ Tests that the second example in doc/usage in the syntax section works """
     from mini_lambda import b, i, s, l, x
     from mini_lambda import Slice, Get, Not, In
-    from mini_lambda import Iter, Repr, Format, Len, Int, Any, Log, DDecimal
+    from mini_lambda import Iter, Repr, Format, Len, Int, Any
+    from mini_lambda.symbols.math_ import Log
+    from mini_lambda.symbols.decimal_ import DDecimal
     from math import log
     from decimal import Decimal
 
@@ -169,9 +177,15 @@ def test_doc_usage_syntax_2():
         expr = 'hello'[0:i]                   # fails
     expr = Get('hello', Slice(0, i))      # OK
     # representing: Repr/Str/Bytes/Sizeof/Hash
+    assert repr(x) == '<_LambdaExpression: x>'
+    x.repr_on = False
     with pytest.raises(FunctionDefinitionError):
-        expr = repr(l)                        # fails
-    expr = Repr(l)                        # OK
+        expr = repr(x)                        # fails
+    expr = Repr(x)                        # OK
+    # propagation
+    with pytest.raises(FunctionDefinitionError):
+        expr = repr(x ** 2)                        # fails
+    expr = Repr(x ** 2)                        # OK
     # formatting with the variable in the args
     with pytest.raises(FunctionDefinitionError):
         expr = '{} {}'.format(s, s)           # fails
@@ -214,7 +228,8 @@ def test_doc_usage_syntax_2():
 
 def test_doc_usage_other_constants():
     """ Tests that the example in doc/usage in the others/constants section works  """
-    from mini_lambda import x, _, E, C
+    from mini_lambda import x, _, C
+    from mini_lambda.symbols.math_ import E
     from math import e
 
     assert str(_(x + e)) == 'x + 2.718281828459045'
@@ -304,7 +319,7 @@ def test_doc_usage_other_functions_2():
 def test_doc_usage_other_classes():
     """ Tests that the example in doc/usage in the others/classes section works """
     from mini_lambda import _, make_lambda_friendly_class
-    from mini_lambda.numpy_ import X
+    from mini_lambda.vars.numpy_ import X
     import numpy as np
     import pandas as pd
 
@@ -318,7 +333,7 @@ def test_doc_usage_other_classes():
 def test_doc_usage_all_at_once():
     """ Tests that the example in doc/usage in the others/anything section works """
     from mini_lambda import _, C
-    from mini_lambda.numpy_ import X
+    from mini_lambda.vars.numpy_ import X
     import numpy as np
     import pandas as pd
 
@@ -331,9 +346,11 @@ def test_doc_usage_all_at_once():
 def test_doc_usage_already_imported():
     """ Tests that the example in doc/usage in the others/preconverted section works """
 
-    from mini_lambda import DDecimal  # Decimal class
     from mini_lambda import Print  # print() function
-    from mini_lambda import Pi  # math.pi constant
+
+    from mini_lambda.symbols.decimal_ import DDecimal  # Decimal class
+    from mini_lambda.symbols.builtins import Print  # print() function
+    from mini_lambda.symbols.math_ import Pi  # math.pi constant
 
 
 def test_doc_optional():
@@ -342,9 +359,9 @@ def test_doc_optional():
     with pytest.raises(ImportError):
         from mini_lambda import X
 
-    from mini_lambda.numpy_ import X
+    from mini_lambda.vars.numpy_ import X
 
     with pytest.raises(ImportError):
         from mini_lambda import df
 
-    from mini_lambda.pandas_ import df
+    from mini_lambda.vars.pandas_ import df
